package com.zanxiang.game.module.manage.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.zanxiang.erp.security.annotation.PreAuthorize;
import com.zanxiang.game.module.manage.pojo.dto.AgentDTO;
import com.zanxiang.game.module.manage.pojo.dto.AgentListDTO;
import com.zanxiang.game.module.manage.pojo.vo.AgentVO;
import com.zanxiang.game.module.manage.service.IAgentService;
import com.zanxiang.module.util.pojo.ResultVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/agent")
public class AgentController {

    @Autowired
    private IAgentService agentService;

    @PreAuthorize(permissionKey = "sdk:agent:list")
    @PostMapping("/list")
    public ResultVO<IPage<AgentVO>> listOfPage(@Validated @RequestBody AgentListDTO dto) {
        return ResultVO.ok(agentService.listOfPage(dto));
    }

    @PreAuthorize(permissionKey = "sdk:agent:add")
    @PostMapping
    public ResultVO<Boolean> add(AgentDTO dto) {
        return ResultVO.ok(agentService.add(dto));
    }


    @PreAuthorize(permissionKey = "sdk:agent:configPutStatus")
    @PutMapping("/configPutStatus/{agentIds}/{putStatus}")
    public ResultVO<Boolean> configPutStatus(@PathVariable("agentIds") List<Long> agentIds, @PathVariable("putStatus") Integer putStatus) {
        return ResultVO.ok(agentService.configPutStatus(agentIds, putStatus));
    }

    @PreAuthorize(permissionKey = "sdk:agent:configBackPolicy")
    @PutMapping("/configBackPolicy/{agentIds}/{backPolicyId}")
    public ResultVO<Boolean> configBackPolicy(@PathVariable("agentIds") List<Long> agentIds, @PathVariable("backPolicyId") Long backPolicyId) {
        return ResultVO.ok(agentService.configBackPolicy(agentIds, backPolicyId));
    }
}
